diff mbox

[GCC/ARM,ping] Rename *_compute_save_reg_mask ()

Message ID 4886fbfc-c95b-87c5-aad6-861ef0fec45d@foss.arm.com
State New
Headers show

Commit Message

Thomas Preudhomme June 5, 2017, 9:39 a.m. UTC
Ping?

Best regards,

Thomas

On 26/05/17 15:19, Thomas Preudhomme wrote:
> Hi,
>
> Name of arm_compute_save_reg_mask and thumb1_compute_save_reg_mask
> suggest that all register saving computation is done in these function
> but these only deal with core registers. The caller
> arm_compute_frame_layout () also computes some of the register saving,
> eg. for VFP registers in 32bit targets. This commit rename former
> functions to refer to core registers saving.
>
> ChangeLog entry is as follows:
>
> *** gcc/ChangeLog ***
>
> 2017-05-24  Thomas Preud'homme  <thomas.preudhomme@arm.com>
>
>     * config/arm/arm.c (arm_compute_save_reg_mask): Rename into ...
>     (arm_compute_save_core_reg_mask): This.
>     (thumb1_compute_save_reg_mask): Rename into ...
>     (thumb1_compute_save_core_reg_mask): This.
>     (arm_compute_save_reg0_reg12_mask): Adapt comment.
>     (arm_compute_frame_layout): Likewise.
>
> Ok for trunk?
>
> Tested with a successful arm-none-eabi build.
>
> Best regards,
>
> Thomas
diff mbox

Patch

diff --git a/gcc/config/arm/arm.c b/gcc/config/arm/arm.c
index c6036fe24abe761540374cfed36edcb953703f5b..6a4ab358d5ee5ceef6a3a1cdfa630dece25cd143 100644
--- a/gcc/config/arm/arm.c
+++ b/gcc/config/arm/arm.c
@@ -130,7 +130,7 @@  static void push_minipool_fix (rtx_insn *, HOST_WIDE_INT, rtx *,
 static void arm_reorg (void);
 static void note_invalid_constants (rtx_insn *, HOST_WIDE_INT, int);
 static unsigned long arm_compute_save_reg0_reg12_mask (void);
-static unsigned long arm_compute_save_reg_mask (void);
+static unsigned long arm_compute_save_core_reg_mask (void);
 static unsigned long arm_isr_value (tree);
 static unsigned long arm_compute_func_type (void);
 static tree arm_handle_fndecl_attribute (tree *, tree, tree, int, bool *);
@@ -19030,7 +19030,7 @@  output_ascii_pseudo_op (FILE *stream, const unsigned char *p, int len)
        && reg >= FIRST_HI_REGNUM && reg <= LAST_HI_REGNUM))
 
 /* Compute the register save mask for registers 0 through 12
-   inclusive.  This code is used by arm_compute_save_reg_mask.  */
+   inclusive.  This code is used by arm_compute_save_core_reg_mask ().  */
 
 static unsigned long
 arm_compute_save_reg0_reg12_mask (void)
@@ -19157,12 +19157,12 @@  arm_compute_static_chain_stack_bytes (void)
   return 0;
 }
 
 /* Compute a bit mask of which registers need to be
    saved on the stack for the current function.
    This is used by arm_compute_frame_layout, which may add extra registers.  */
 
 static unsigned long
-arm_compute_save_reg_mask (void)
+arm_compute_save_core_reg_mask (void)
 {
   unsigned int save_reg_mask = 0;
   unsigned long func_type = arm_current_func_type ();
@@ -19244,10 +19244,10 @@  arm_compute_save_reg_mask (void)
   return save_reg_mask;
 }
 
 /* Compute a bit mask of which registers need to be
    saved on the stack for the current function.  */
 static unsigned long
-thumb1_compute_save_reg_mask (void)
+thumb1_compute_save_core_reg_mask (void)
 {
   unsigned long mask;
   unsigned reg;
@@ -20783,7 +20783,7 @@  any_sibcall_could_use_r3 (void)
   eliminating some of the registers.
 
   The values returned by this function must reflect the behavior
-  of arm_expand_prologue() and arm_compute_save_reg_mask().
+  of arm_expand_prologue () and arm_compute_save_core_reg_mask ().
 
   The sign of the number returned reflects the direction of stack
   growth, so the values are positive for all eliminations except
@@ -20839,7 +20839,7 @@  arm_compute_frame_layout (void)
     {
       unsigned int regno;
 
-      offsets->saved_regs_mask = arm_compute_save_reg_mask ();
+      offsets->saved_regs_mask = arm_compute_save_core_reg_mask ();
       core_saved = bit_count (offsets->saved_regs_mask) * 4;
       saved = core_saved;
 
@@ -20870,7 +20870,7 @@  arm_compute_frame_layout (void)
     }
   else /* TARGET_THUMB1 */
     {
-      offsets->saved_regs_mask = thumb1_compute_save_reg_mask ();
+      offsets->saved_regs_mask = thumb1_compute_save_core_reg_mask ();
       core_saved = bit_count (offsets->saved_regs_mask) * 4;
       saved = core_saved;
       if (TARGET_BACKTRACE)
@@ -19157,12 +19157,12 @@  arm_compute_static_chain_stack_bytes (void)
 }
 
-/* Compute a bit mask of which registers need to be
+/* Compute a bit mask of which core registers need to be
    saved on the stack for the current function.
    This is used by arm_compute_frame_layout, which may add extra registers.  */
@@ -19244,10 +19244,10 @@  arm_compute_save_reg_mask (void)
 }
 
-/* Compute a bit mask of which registers need to be
+/* Compute a bit mask of which core registers need to be
    saved on the stack for the current function.  */
 static unsigned long